/***********************************************************************/
/***********************************************************************/
/* Job Name:DI_ETL_Purge_profiling_project                             */
/* The utility will help to Purge the old Profiling Project            */ 
/* From the System                                                     */
/* You can control the usage of the Parameter by tuning the following  */
/* JOB_PARAM                                                           */
/* Following JOB_PARAM are used                                        */
/* 1.PURGE_DT - All project before the specified date will be purged   */
/* 2.PURGE_USING_STG = 1, Specify the Project to purged in a staging   */
/*                     table didm_stg.stg_project_purge                */
/* 3.PURGE_ONLY_PUBLISHED=1, If set to 1 only purge the published      */ 
/*                           Project with UPDATED_DTTM less than       */ 
/*                           PURGE_DT                                  */
/* 4.PURGE_ONLY_PUBLISHED=0,If set to 0 purge all the Profiling project*/ 
/*                           with UPDATED_DTTM less than PURGE_DT      */
/* 5.PURGE_AUDIT_ONLY= 1, Will not purge the Project, create a         */
/*                        audit dataset PROFILING_PROJECT_AUDIT        */ 
/* 6.PURGE_AUDIT_ONLY= 0, Start Purging the project                    */
/*                                                                     */
/***********************************************************************/
/***********************************************************************/
%let etls_jobName = %nrquote(DI_ETL_Purge_profiling_project);

%global job_rc trans_rc sqlrc etls_recordsBefore etls_recordsAfter;
%global purge_dt purge_using_stg purge_only_published purge_audit_only;
%let syscc=0;
%let etls_startTime = %sysfunc(datetime(),datetime.);
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib=DIDM_STG;
%let etls_table=stg_project_purge;

%etl_initjobparam (monlib=di_mon, jobname=%nrquote(&etls_jobName));


%macro di_etl_purge_szpf_prjct_mn();


/*************************************************************/
/***** START DELETING PROJECT FROM SAS************************/
/*************************************************************/

%local num_parallel_executions;


%di_util_global_setting_spec(spec_nm=NUM_PARALLEL_EXECUTIONS,
                             app=ALL,
                             _spec_value=num_parallel_executions,
                             optional=1);

%if &syscc gt 4 %then %do;
     %goto rppfexit;
%end;

proc sql noprint;
    create table work.sas_delete_arg as 
	select distinct profiling_project_sk as profiling_project
	from di_trans.ztmp_project_purge
    ;
quit;

%if %di_util_nobs(work.sas_delete_arg) eq 0 %then %do;
    %put NOTE:No Project to purge.,exiting;
    %goto rppfexit;
%end;


 %di_util_mp_connect(mac_name=di_etl_project_delete_sas,
                       arg_table=work.sas_delete_arg,
                       nm_prll_exec=&num_parallel_executions,
                       wait_interval=5,
                       prefix=di_etl_project_delete_sas)



%if &syscc gt 4 %then %do;
    %goto rppfexit;
%end;


/*************************************************************/
/***** END DELETING PROJECT FROM SAS************************/
/*************************************************************/




/*************************************************************/
/***** START DELETING PROJECT FROM RDBMS**********************/
/*************************************************************/

data work.delete_arg;
    attrib tablename length=$32.;
	attrib joinkey length=$32.;
	attrib jointable length=$32.;
	stop;
run;

proc sql;
INSERT INTO work.delete_arg(tablename,joinkey,jointable)
values ('PRF_DISTRIBUTION','PROFILE_SK','ztmp_profile_purge')
values ('PRF_RSLT_PROFILE_RMSD','PROFILE_SK','ztmp_profile_purge')
values ('PRF_ATTR','PROFILE_SK','ztmp_profile_purge')
values ('PRF_RSLT_PROFILING','PRF_PLAN_SK','ztmp_plan_purge')
values ('PRF_PROFILE','PRF_PLAN_SK','ztmp_plan_purge')
values ('PRF_PLAN','PRF_SCENARIO_SK','ztmp_scenario_purge')
values ('PRF_RSLT_SC_ACCURACY','PROFILING_PROJECT_SK','ztmp_project_purge')
values ('PRF_RSLT_SC_ATTR_PVALUE','PROFILING_PROJECT_SK','ztmp_project_purge')
values ('PRF_RSLT_STORE_CLSF','PROFILING_PROJECT_SK','ztmp_project_purge')
values ('PRF_RSLT_STORE_GROUP','PROFILING_PROJECT_SK','ztmp_project_purge')
values ('PRF_RSLT_STORE_GROUP_DISTRIB','PROFILING_PROJECT_SK','ztmp_project_purge')
values ('PRF_STORE_GROUP','PROFILING_PROJECT_SK','ztmp_project_purge')
values ('PRF_RSLT_STORE_GROUP_RMSD','PROFILING_PROJECT_SK','ztmp_project_purge')
values ('PRF_PROD_SIZE_EXCLUDE','PROFILING_PROJECT_SK','ztmp_project_purge')
values ('PRF_RSLT_PREPROCESS','PROFILING_PROJECT_SK','ztmp_project_purge')
values ('PRF_SIZESET','PROFILING_PROJECT_SK','ztmp_project_purge')
values ('PRF_SIZESET_MBR','PROFILING_PROJECT_SK','ztmp_project_purge')
values ('PRF_PROD_PARTITION','PROFILING_PROJECT_SK','ztmp_project_purge')
values ('PRF_SCOPE_FILTER','PROFILING_PROJECT_SK','ztmp_project_purge')
values ('PRF_SCENARIO','PROFILING_PROJECT_SK','ztmp_project_purge')
values ('PROFILING_PROJECT','PROFILING_PROJECT_SK','ztmp_project_purge')
;
quit;

%if &syscc gt 4 %then %do;
    %goto rppfexit;
%end;



 %di_util_mp_connect(mac_name=di_etl_purge_parallel,
                      arg_table=work.delete_arg,
                       nm_prll_exec=&num_parallel_executions,
                       wait_interval=5,
                       prefix=di_etl_purge_parallel)

%if &syscc gt 4 %then %do;
    %goto rppfexit;
%end;

/*Start Delete PROCESS_PARAMETER*/


%let m_sql_statement = %str(

DELETE FROM di_trans.PROCESS_PARAMETER  
WHERE PROCESS_SK in ( 
SELECT PROCESS_SK from di_trans.PROCESS_STATUS a,
                       di_trans.ztmp_project_purge b
where a.CONTEXT_SK=b.PROFILING_PROJECT_SK
and a.PROCESS_NM in ('SizeProfilingActivityRun','SizeProfilingProfilesGen',
                    'SizeProfilingPublishUnpublish')
)     
);

%di_dm_trans_exe(
   pass_through_sql=%quote(&m_sql_statement));

%if &syscc gt 4 %then %do;
    %goto rppfexit;
%end;

/*End Delete PROCESS_PARAMETER*/


/*Start Delete PROCESS_STATUS*/
%let m_sql_statement = %str(
DELETE  from di_trans.PROCESS_STATUS
where CONTEXT_SK in (select PROFILING_PROJECT_SK
                     from di_trans.ztmp_project_purge 
                    )
and PROCESS_NM in ('SizeProfilingActivityRun','SizeProfilingProfilesGen',
                    'SizeProfilingPublishUnpublish')     
);


%di_dm_trans_exe(
   pass_through_sql=%quote(&m_sql_statement));

%if &syscc gt 4 %then %do;
    %goto rppfexit;
%end;


/*End delete PROCESS_STATUS*/


/*Start Delete PRF_ATTR_CONFIG*/

%let m_sql_statement = %str(
DELETE  from di_trans.PRF_ATTR_CONFIG
where PRF_ATTR_CONFIG_SK in (select PRF_SCENARIO_SK
                     from di_trans.ztmp_scenario_purge 
                    )
and PRF_CONFIG_TYPE in (1,0)     
);


%di_dm_trans_exe(
   pass_through_sql=%quote(&m_sql_statement));

%if &syscc gt 4 %then %do;
    %goto rppfexit;
%end;


/*End delete PRF_ATTR_CONFIG*/




/*Start Delete PRF_ATTR_CONFIG*/

%let m_sql_statement = %str(
DELETE  from di_trans.PRF_JOB
where CONTEXT_SK in (select PROFILING_PROJECT_SK
                     from di_trans.ztmp_project_purge 
                    )
and JOB_TYPE in (1)     
);


%di_dm_trans_exe(
   pass_through_sql=%quote(&m_sql_statement));

%if &syscc gt 4 %then %do;
    %goto rppfexit;
%end;


%let m_sql_statement = %str(
DELETE  from di_trans.PRF_CONFIG
where PRF_CONFIG_SK in (select PROFILING_PROJECT_SK
                     from di_trans.ztmp_project_purge 
                    )
and PRF_CONFIG_TYPE in (1)     
);


%di_dm_trans_exe(
   pass_through_sql=%quote(&m_sql_statement));

%if &syscc gt 4 %then %do;
    %goto rppfexit;
%end;

%let m_sql_statement = %str(
DELETE  from di_trans.PRF_CONFIG
where PRF_CONFIG_SK in (select PRF_SCENARIO_SK
                     from di_trans.ztmp_scenario_purge 
                    )
and PRF_CONFIG_TYPE in (2)     
and SPEC_NM in ('max_num_of_cluster','min_cluster_size','lrm_ccc',
               'applied_str_grp_rule','pending_str_grp_rule',
               'max_projects_to_apply_rule','super_sizeset_fill_zero_sales')
);


%di_dm_trans_exe(
   pass_through_sql=%quote(&m_sql_statement));

%if &syscc gt 4 %then %do;
    %goto rppfexit;
%end;

%let m_sql_statement = %str(
DELETE  from di_trans.PRF_CONFIG
where PRF_CONFIG_SK in (select PRF_SCENARIO_SK
                     from di_trans.ztmp_scenario_purge 
                    )
and PRF_CONFIG_TYPE in (3)     
);


%di_dm_trans_exe(
   pass_through_sql=%quote(&m_sql_statement));

%if &syscc gt 4 %then %do;
    %goto rppfexit;
%end;


/*End Delete PRF_ATTR_CONFIG*/

%let m_sql_statement = %str(
DELETE FROM PRF_TAG t WHERE NOT EXISTS 
(SELECT pt.PRF_TAG_SK FROM PROFILING_PROJECT_TAG pt 
WHERE pt.PRF_TAG_SK = t.PRF_TAG_SK )
);

%di_dm_trans_exe(
   pass_through_sql=%quote(&m_sql_statement));

%if &syscc gt 4 %then %do;
    %goto rppfexit;
%end;


/*End delete PRF_ATTR_CONFIG*/





/***** END DELETING PROJECT FROM RDBMS*****/

%rppfexit:

%mend di_etl_purge_szpf_prjct_mn;


%macro di_etl_purge_profiling_main();


%if &purge_using_stg ne 1 %then %do;
%if %length(&purge_dt) eq 0 %then %do;
     %put ERROR:JOB_PARAM purge_dt is invalid or missing;
	 %let syscc=99;
     %goto exit;
%end;
%else %do;
    %let ndate =%sysfunc(inputn(&purge_dt:00:00:00, DATETIME.));
    %put &ndate;
	%if %length(&ndate) eq 0 or &ndate eq . %then %do;
	    %put ERROR:JOB_PARAM purge_dt is invalid or missing;
	    %let syscc=99;
	    %goto exit;
	%end;
	%else %do;
	   %let rdbms_dt = %di_util_date_to_dbms(&ndate,type=datetime);
	%end;
%end;
%end;
%else %do;
     %if not %sysfunc(exist(didm_stg.stg_project_purge)) %then %do;
	       %put ERROR:didm_stg.stg_project_purge,table does not exist;
	       %let syscc=99;
	       %goto exit;
	 %end;
	 %if %di_util_nobs(didm_stg.stg_project_purge) eq 0 %then %do;
	      %put NOTE:No data to purge.Exiting without processing;
	      %goto exit; 
	 %end;
%end;

/*************************************************************/
/****Prechecking to check the existance of temproary table****/
/*************************************************************/

%if %sysfunc(exist(di_trans.ztmp_project_purge)) %then %do;
    proc sql noprint;
	     drop table di_trans.ztmp_project_purge;
	quit;
%end;

%if &syscc gt 4 %then %do;
    %goto exit;
%end;

%if %sysfunc(exist(di_trans.ztmp_scenario_purge)) %then %do;
    proc sql noprint;
	     drop table di_trans.ztmp_scenario_purge;
	quit;
%end;

%if &syscc gt 4 %then %do;
    %goto exit;
%end;


%if %sysfunc(exist(di_trans.ztmp_plan_purge)) %then %do;
    proc sql noprint;
	     drop table di_trans.ztmp_plan_purge;
	quit;
%end;

%if &syscc gt 4 %then %do;
    %goto exit;
%end;

%if %sysfunc(exist(di_trans.ztmp_profile_purge)) %then %do;
    proc sql noprint;
	     drop table di_trans.ztmp_profile_purge;
	quit;
%end;

%if &syscc gt 4 %then %do;
    %goto exit;
%end;

/*************************************************************/
/*************************************************************/
/*************************************************************/


/*************************************************************/
/***Create temprory table for deleting Project related data***/
/*************************************************************/
%if &purge_using_stg = 1 %then %do;

      %if %di_util_nobs(didm_stg.stg_project_purge) gt 0 %then %do;

	        %if %sysfunc(exist(di_trans.stg_project_purge)) %then %do;
			     proc sql noprint;
				      drop table di_trans.stg_project_purge;
				 quit;
			%end;


			proc sql noprint;
			    create table di_trans.stg_project_purge
				as select distinct PROJECT_NM from didm_stg.stg_project_purge;
			quit;
			
            %if &syscc gt 4 %then %do;
                %goto exit;
            %end;

             %let m_sql_statement = %str(
              create table di_trans.ztmp_project_purge as 
              select distinct a.profiling_project_sk
              from di_trans.profiling_project a ,
			       di_trans.stg_project_purge b,
                   di_trans.prf_scenario c 
              where a.PROJECT_NM = b.PROJECT_NM 
			       and a.profiling_project_sk = c.profiling_project_sk
             );

            %di_dm_trans_exe(
            pass_through_sql=%quote(&m_sql_statement));

            %if &syscc gt 4 %then %do;
                %goto exit;
            %end;

 	  %end;
    

%end;
%else %do;

%let additional_filter=;
%if &purge_only_published=1 %then %do;
    %let additional_filter=%str( AND C.STATUS_CD=4);
%end;

%let m_sql_statement = %str(
create table di_trans.ztmp_project_purge as 
select distinct a.profiling_project_sk
       from di_trans.profiling_project a,
	        di_trans.prf_scenario c 
       where c.updated_dttm < &rdbms_dt
	   and a.profiling_project_sk=c.profiling_project_sk
	   &additional_filter
);
 

%di_dm_trans_exe(
   pass_through_sql=%quote(&m_sql_statement));

%if &syscc gt 4 %then %do;
    %goto exit;
%end;

%end;

%if &purge_audit_only=1 %then %do;
    proc sql noprint;
	    create table di_mon.PROFILING_PROJECT_AUDIT
		as select a.profiling_project_sk,
		          a.PROJECT_NM
			from di_trans.profiling_project  as a
			where a.profiling_project_sk in 
              (select profiling_project_sk
              from di_trans.ztmp_project_purge);
	quit;
	%put NOTE: Ran with Audit only option.;
	%put NOTE: The Project which will be purged can be seen,in di_mon.PROFILING_PROJECT_AUDIT.;
	%put NOTE: Set JOB PARAM PURGE_AUDIT_ONLY to 0 to purge the projects.;
	%goto exit;
%end;

/*************************************************************/
/***Create temprory table for deleting Scenariorelated data***/
/*************************************************************/
%let m_sql_statement = %str(
create table di_trans.ztmp_scenario_purge as 
select distinct PRF_SCENARIO_SK
       from di_trans.Prf_scenario 
	   where profiling_project_sk in ( select profiling_project_sk from di_trans.ztmp_project_purge)
);
 

%di_dm_trans_exe(
   pass_through_sql=%quote(&m_sql_statement));

%if &syscc gt 4 %then %do;
    %goto exit;
%end;

/*************************************************************/
/***Create temprory table for deleting plan related data******/
/*************************************************************/
%let m_sql_statement = %str(
create table di_trans.ztmp_plan_purge as 
select distinct PRF_PLAN_SK
       from di_trans.Prf_plan 
	   where PRF_SCENARIO_SK in ( select PRF_SCENARIO_SK from di_trans.ztmp_scenario_purge)
);
 

%di_dm_trans_exe(
   pass_through_sql=%quote(&m_sql_statement));

%if &syscc gt 4 %then %do;
    %goto exit;
%end;

/*************************************************************/
/***Create temprory table for deleting profile related data***/
/*************************************************************/

%let m_sql_statement = %str(
create table di_trans.ztmp_profile_purge as 
select distinct PROFILE_SK
       from di_trans.Prf_profile 
	   where PRF_PLAN_SK in ( select PRF_PLAN_SK from di_trans.ztmp_plan_purge)
);
 

%di_dm_trans_exe(
   pass_through_sql=%quote(&m_sql_statement));

%if &syscc gt 4 %then %do;
    %goto exit;
%end;


%di_etl_purge_szpf_prjct_mn()


%if &syscc gt 4 %then %do;
    %goto exit;
%end;

%exit:

%if %sysfunc(exist(di_trans.tmp_project_purge)) %then %do;
    proc sql noprint;
	     drop table di_trans.tmp_project_purge;
	quit;
%end;

%if %sysfunc(exist(di_trans.ztmp_scenario_purge)) %then %do;
    proc sql noprint;
	     drop table di_trans.ztmp_scenario_purge;
	quit;
%end;

%if %sysfunc(exist(di_trans.ztmp_plan_purge)) %then %do;
    proc sql noprint;
	     drop table di_trans.ztmp_plan_purge;
	quit;
%end;


%if %sysfunc(exist(di_trans.ztmp_profile_purge)) %then %do;
    proc sql noprint;
	     drop table di_trans.ztmp_profile_purge;
	quit;
%end;

%if &syscc gt 4 %then %do;
    %put ERROR:Job DI_ETL_Purge_profiling_project, end with ERROR:;
%end;



%mend di_etl_purge_profiling_main;



%di_etl_purge_profiling_main()

%di_etl_rcSet(error=&syscc,code=job_rc);

%let etls_endTime = %sysfunc(datetime(),datetime.);
%etls_sendJobStatus;
